abacusai.model_blueprint_stage — AbacusAI documentation

# abacusai.model_blueprint_stage

## Classes

`ModelBlueprintStage` | A stage in the model blueprint export process.

## Module Contents

class abacusai.model_blueprint_stage.ModelBlueprintStage(client, stageName=None, displayName=None, description=None, params=None, predecessors=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A stage in the model blueprint export process.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - stageName (str) – The name of the stage.

    - displayName (str) – The display name of the stage.

    - description (str) – The description of the stage.

    - params (dict) – The parameters for the stage.

    - predecessors (list) – A list of stages that occur directly before this stage.

  stage_name
  display_name
  description
  params
  predecessors
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict